gMCP(graph, pvalues, test, correlation, alpha=0.05,
approxEps=TRUE, eps=10^(-3), ..., useC=FALSE,
verbose=FALSE, keepWeights=TRUE, adjPValues=TRUE)graphMCP."Simes" the weighted Simes test will be performed for each
subset of hypotheses. Further alternatives will be added in the future."Dunnett", "Tukey", "Sequen", "AVE", "Changepoint", "Williams", "Marcus", "McDermott", "UmbrellaWilliams", "GrandMean".
In this case please add a numeric paraeps.TRUE neither adjusted p-values nor intermediate graphs are returned,
but the calculation is sped up by using code written in C. THIS CODE IS NOT FOR PRODUCTIVE USE YET!
If approxEps is FALSE and the graphTRUE verbose output is generated during
sequentially rejection steps.FALSE the weight of a node without outgoing edges is set to 0 if it is removed.
Otherwise it keeps its weight.FALSE no adjusted p-values will be calculated.
Especially for the weighted Simes test this will result in significantly less calculations in most cases.gMCPResult, more specifically a list with elementsBretz F., Posch M., Glimm E., Klinglmueller F., Maurer W., Rohmeyer K. (2011): Graphical approaches for multiple endpoint problems using weighted Bonferroni, Simes or parametric tests - to appear.
Strassburger K., Bretz F.: Compatible simultaneous lower confidence bounds for the Holm procedure and other Bonferroni based closed tests. Statistics in Medicine 2008; 27:4914-4927.
Hommel G., Bretz F., Maurer W.: Powerful short-cuts for multiple testing procedures with special reference to gatekeeping strategies. Statistics in Medicine 2007; 26:4063-4073.
Guilbaud O.: Simultaneous confidence regions corresponding to Holm's stepdown procedure and other closed-testing procedures. Biometrical Journal 2008; 50:678-692.
graphMCP
graphNELg <- BonferroniHolm(5)
gMCP(g, pvalues=c(0.01, 0.02, 0.04, 0.04, 0.7))Run the code above in your browser using DataLab